﻿#region Imported Namespaces

//.NET common used namespaces
using System;
using System.Windows.Forms;
using System.Collections.Generic;

//Revit.NET common used namespaces
using Autodesk.Revit.ApplicationServices;
using Autodesk.Revit.Attributes;
using Autodesk.Revit.DB;
using Autodesk.Revit.UI;
using Autodesk.Revit.UI.Selection;
using System.Text;

#endregion

namespace RevitDevTV
{
    [Transaction(TransactionMode.Automatic)]
    [Regeneration(RegenerationOption.Manual)]
    public class AdskCommand : IExternalCommand
    {
        /// <summary>
        /// The one and only method required by the IExternalCommand interface,
        /// the main entry point for every external command.
        /// </summary>
        /// <param name="commandData">Input argument providing access to the Revit application and its documents and their properties.</param>
        /// <param name="message">Return argument to display a message to the user in case of error if Result is not Succeeded.</param>
        /// <param name="elements">Return argument to highlight elements on the graphics screen if Result is not Succeeded.</param>
        /// <returns>Cancelled, Failed or Succeeded Result code.</returns>
        public Result Execute(
            ExternalCommandData commandData,
            ref string message,
            ElementSet elements)
        {
            //TODO: Add your code here
            UIApplication uiApp = commandData.Application;
            UIDocument uiDoc = uiApp.ActiveUIDocument;

            //vamos acessar a seleção
            Selection sel = uiDoc.Selection;

            //agora podemos iterar pela seleção
            foreach (Element ele in sel.Elements)
            {
                //vamos formatar uma string com alguns dados
                string eleInfo = string.Format(
                    "Nome: {0}\nCategoria: {1}",
                    ele.Name, ele.Category.Name);

                TaskDialog.Show("Seleção",
                    eleInfo);
            }

            //vamos criar um filtro
            FilteredElementCollector portas =
                new FilteredElementCollector(uiDoc.Document);

            //em seguida adicionar os critérios
            portas.OfClass(typeof(FamilyInstance));
            portas.OfCategory(BuiltInCategory.OST_Doors);

            //repetição com foreach
            foreach (Element porta in portas)
            {
                StringBuilder infoPorta = new StringBuilder();
                infoPorta.AppendFormat("Nome: {0}", porta.Name);

                //vamor percorrer a lista de parametros (de cada porta)
                foreach (Parameter param in porta.Parameters)
                {
                    //mostrar o nome do parametro
                    infoPorta.AppendFormat("\nParametro {0}: ", 
                        param.Definition.Name);

                    //verificar o tipo armazendo para exibir o valor
                    switch (param.StorageType)
                    {
                        case StorageType.String:
                            infoPorta.Append(param.AsString());
                            break;
                        case StorageType.Double:
                            infoPorta.Append(param.AsDouble().ToString());
                            break;
                        default:
                            infoPorta.Append("Para casa");
                            break;
                    }
                }

                //exebir a informação
                TaskDialog.Show("Porta selecionada", infoPorta.ToString());
            }


            //Must return some code
            return Result.Succeeded;
        }
    }
}
